==> hs-aeson-0.3.2.11.tbz: lib/ghc-7.0.3/cabal/aeson-0.3.2.11/register.sh <==
#!/bin/sh
echo 'name: aeson
version: 0.3.2.11
id: aeson-0.3.2.11-15795b131494e7b81767cd00eb4ed261

license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@mailrank.com>
stability: experimental
homepage: http://github.com/mailrank/aeson
package-url:
description: A JSON parsing and encoding library optimized for ease of use
             and high performance.
             .
             /Note/: if you use GHCi or Template Haskell, please see the
             @README@ file for important details about building this package,
             and other packages that depend on it:
             <https://github.com/mailrank/aeson#readme>
             .
             Parsing performance on a late 2010 MacBook Pro (2.66GHz Core i7),
             for mostly-English tweets from Twitter'\''s JSON search API:
             .
             * 0.8 KB, 32-bit GHC 6.12.3: 30538 msg\/sec (24.9 MB\/sec)
             .
             * 0.8 KB, 64-bit GHC 7.0.3: 31204 msg\/sec (25.4 MB\/sec)
             .
             * 6.4 KB, 32-bit GHC 6.12.3: 6731 msg\/sec (42.3 MB\/sec)
             .
             * 6.4 KB, 64-bit GHC 7.0.3: 6627 msg\/sec (41.7 MB\/sec)
             .
             * 11.8 KB, 32-bit GHC 6.12.3: 3751 msg\/sec (43.2 MB\/sec)
             .
             * 11.8 KB, 64-bit GHC 7.0.3: 3381 msg\/sec (38.9 MB\/sec)
             .
             * 31.2 KB, 32-bit GHC 6.12.3: 1306 msg\/sec (39.8 MB\/sec)
             .
             * 31.2 KB, 64-bit GHC 7.0.3: 1132 msg\/sec (34.5 MB\/sec)
             .
             * 61.5 KB, 32-bit GHC 6.12.3: 616 msg\/sec (37.0 MB\/sec)
             .
             * 61.5 KB, 64-bit GHC 7.0.3: 534 msg\/sec (32.1 MB\/sec)
             .
             Handling heavily-escaped text is a little more work.  Here is
             parsing performance with Japanese tweets, where much of the text
             is entirely Unicode-escaped.
             .
             * 14.6 KB, 32-bit GHC 6.12.3: 2315 msg\/sec (33.1 MB\/sec)
             .
             * 14.6 KB, 64-bit GHC 7.0.3: 1986 msg\/sec (28.4 MB\/sec)
             .
             * 44.1 KB, 32-bit GHC 6.12.3: 712 msg\/sec (30.7 MB\/sec)
             .
             * 44.1 KB, 64-bit GHC 7.0.3: 634 msg\/sec (27.3 MB\/sec)
             .
             * 82.9 KB, 32-bit GHC 6.12.3: 377 msg\/sec (30.5 MB\/sec)
             .
             * 82.9 KB, 64-bit GHC 7.0.3: 332 msg\/sec (26.9 MB\/sec)
             .
             Encoding performance on the same machine and data:
             .
             * English, 854 bytes: 43439 msg\/sec (35.4 MB/sec)
             .
             * English, 6.4 KB: 7127 msg\/sec (44.8 MB/sec)
             .
             * Engish, 61.5 KB: 765 msg\/sec (46.0 MB/sec)
             .
             * Japanese, 14.6 KB: 4727 msg\/sec (67.5 MB/sec)
             .
             * Japanese, 44.1 KB: 1505 msg\/sec (64.8 MB/sec)
             .
             (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
author: Bryan O'\''Sullivan <bos@mailrank.com>
exposed: True
exposed-modules: Data.Aeson Data.Aeson.Encode Data.Aeson.Generic
                 Data.Aeson.Parser Data.Aeson.Types
hidden-modules: Data.Aeson.Functions
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/aeson-0.3.2.11
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/aeson-0.3.2.11
              /usr/local/lib
hs-libraries: HSaeson-0.3.2.11
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: attoparsec-0.9.1.1-4d3d2f136ac4fa8436d554496fbcc301
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         blaze-builder-0.3.0.1-60b11fc303d7209d1de9852ef681017b
         blaze-textual-0.2.0.4-c76fc9750daee188b3361f9927269ad8
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         deepseq-1.1.0.2-677f443f43caba0d312ab80199d4a233
         hashable-1.1.2.1-e15a71a3e1d5829d743a94d9cba24dfa
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
         old-locale-1.0.0.2-cc522edd16b73a70b897598c5f5d20c7
         syb-0.3-8a51ec8e05a2a260bc0e1bb18be953b0
         text-0.11.0.6-c8599590347c5c77cb2239f432e5bbf9
         time-1.2.0.3-4f1bed38bdf37d398ba8f4311cbdac4a
         unordered-containers-0.1.4.2-a9f95cc1cd303f1ddc9dd2aad699b1a5
         vector-0.7.1-cc2fb92eb9303daece32129c287a37b8
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/aeson-0.3.2.11/html/aeson.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/aeson-0.3.2.11/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-aeson-0.4.0.1.tbz: lib/ghc-7.0.4/cabal/aeson-0.4.0.1/register.sh <==
#!/bin/sh
echo 'name: aeson
version: 0.4.0.1
id: aeson-0.4.0.1-f398dea0ec7e734cb6447d520b4aa8ae

license: BSD3
copyright: (c) 2011 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
package-url:
description: A JSON parsing and encoding library optimized for ease of use
             and high performance.
             .
             To get started, see the documentation for the @Data.Aeson@ module
             below.
             .
             For release notes, see
             <https://github.com/bos/aeson/blob/master/release-notes.markdown>
             .
             /Note/: if you use GHCi or Template Haskell, please see the
             @README@ file for important details about building this package,
             and other packages that depend on it:
             <https://github.com/bos/aeson#readme>
             .
             Parsing performance on a late 2010 MacBook Pro (2.66GHz Core i7),
             for mostly-English tweets from Twitter'\''s JSON search API:
             .
             * 0.8 KB, 32-bit GHC 6.12.3: 30538 msg\/sec (24.9 MB\/sec)
             .
             * 0.8 KB, 64-bit GHC 7.0.3: 31204 msg\/sec (25.4 MB\/sec)
             .
             * 6.4 KB, 32-bit GHC 6.12.3: 6731 msg\/sec (42.3 MB\/sec)
             .
             * 6.4 KB, 64-bit GHC 7.0.3: 6627 msg\/sec (41.7 MB\/sec)
             .
             * 11.8 KB, 32-bit GHC 6.12.3: 3751 msg\/sec (43.2 MB\/sec)
             .
             * 11.8 KB, 64-bit GHC 7.0.3: 3381 msg\/sec (38.9 MB\/sec)
             .
             * 31.2 KB, 32-bit GHC 6.12.3: 1306 msg\/sec (39.8 MB\/sec)
             .
             * 31.2 KB, 64-bit GHC 7.0.3: 1132 msg\/sec (34.5 MB\/sec)
             .
             * 61.5 KB, 32-bit GHC 6.12.3: 616 msg\/sec (37.0 MB\/sec)
             .
             * 61.5 KB, 64-bit GHC 7.0.3: 534 msg\/sec (32.1 MB\/sec)
             .
             Handling heavily-escaped text is a little more work.  Here is
             parsing performance with Japanese tweets, where much of the text
             is entirely Unicode-escaped.
             .
             * 14.6 KB, 32-bit GHC 6.12.3: 2315 msg\/sec (33.1 MB\/sec)
             .
             * 14.6 KB, 64-bit GHC 7.0.3: 1986 msg\/sec (28.4 MB\/sec)
             .
             * 44.1 KB, 32-bit GHC 6.12.3: 712 msg\/sec (30.7 MB\/sec)
             .
             * 44.1 KB, 64-bit GHC 7.0.3: 634 msg\/sec (27.3 MB\/sec)
             .
             * 82.9 KB, 32-bit GHC 6.12.3: 377 msg\/sec (30.5 MB\/sec)
             .
             * 82.9 KB, 64-bit GHC 7.0.3: 332 msg\/sec (26.9 MB\/sec)
             .
             Encoding performance on the same machine and data:
             .
             * English, 854 bytes: 43439 msg\/sec (35.4 MB/sec)
             .
             * English, 6.4 KB: 7127 msg\/sec (44.8 MB/sec)
             .
             * Engish, 61.5 KB: 765 msg\/sec (46.0 MB/sec)
             .
             * Japanese, 14.6 KB: 4727 msg\/sec (67.5 MB/sec)
             .
             * Japanese, 44.1 KB: 1505 msg\/sec (64.8 MB/sec)
             .
             (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules: Data.Aeson Data.Aeson.Encode Data.Aeson.Generic
                 Data.Aeson.Parser Data.Aeson.Types Data.Aeson.TH
hidden-modules: Data.Aeson.Functions Data.Aeson.Parser.Internal
                Data.Aeson.Types.Class Data.Aeson.Types.Internal
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/aeson-0.4.0.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/aeson-0.4.0.1
              /usr/local/lib
hs-libraries: HSaeson-0.4.0.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: attoparsec-0.10.1.0-d48602bcab8a927c27afa06cc0583921
         base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         blaze-builder-0.3.1.0-6a36510708b3ea2d7409287ec7d56f4c
         blaze-textual-0.2.0.6-3511015cddc77bd13630df67f35e9f60
         bytestring-0.9.1.10-94a0a1c920aee21a485bdf21fd51b2be
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         deepseq-1.1.0.2-677f443f43caba0d312ab80199d4a233
         hashable-1.1.2.2-c43bd88712c9ef99008fd36c4aedbd63
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
         old-locale-1.0.0.2-cc522edd16b73a70b897598c5f5d20c7
         syb-0.3.3-43363d15978052669a36ccb62324e276
         template-haskell-2.5.0.0-adafdd03731a91bbb4c278042a2e11df
         text-0.11.1.5-b4f492f688b9a01c2b4d3a9904e832bc
         time-1.2.0.3-4f1bed38bdf37d398ba8f4311cbdac4a
         unordered-containers-0.1.4.6-62035370633ff5fdd6ab47b62ed9ec07
         vector-0.9.1-86d51bed78dc5d006e4d1f3d9ea44e66
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/aeson-0.4.0.1/html/aeson.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/aeson-0.4.0.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
